Learn R Programming

ck37r (version 1.0.0)

load_all_code: Load all R files in a library directory.

Description

Load all R files in a library directory.

Usage

load_all_code(lib_dir = "lib", exclude_files = c("function_library.R"),
  file_pattern = "\\.R$", recursive = T, verbose = T)

Arguments

lib_dir

Directory contains the source code files.

exclude_files

Exclude a list of files; exclude function_library.R by default because we presume that is the main R library file.

file_pattern

Regular expression for files to load, defaults to *.R

recursive

If TRUE also recurse into subdirectories.

verbose

If TRUE display additional output during execution.

Examples

Run this code

library(ck37r)

# Here R is a subdirectory with a bunch of .R files to load.
load_all_code("R")

Run the code above in your browser using DataLab